local addon, PowerUp = ...

-- Defaults
local defaults = {
	texture = "Interface\\AddOns\\PowerUp\\texture",
	width = 250,
	height = 10,
	point = "CENTER",
	x = 0,
	y = 200,
	hidewhenempty = true,	-- hides the frame when empty
	colors = {
		WARLOCK = {
			r = .58,
			g = .51,
			b = .79,
		},
		PALADIN = {
			r = 1,
			g = 1,
			b = 0,
		},
		overlay = {
			r = 0,
			g = 1,
			b = 0,
		}
	},
	showOverlay = true,		-- positions an overlay on top of the holypowers guesstimating when the next power will expire
	overlayAlpha = .5,		-- the alpha of the overlay
	useGradient = true,		-- if true, the overlay will fade from green (@max) to red (@min), otherwise the color below is used
	hideBlizz = true,		-- hide default Blizzard powerbars
}

PowerUp.defaults = defaults

local title, desc = select(2, GetAddOnInfo(addon))
local f = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
PowerUp.panel = f
f.name = title
f:Hide()

f:SetScript("OnShow", function(self)
	db = PowerUpDB
	
	-- Header
	local header = self:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	header:SetPoint("TOPLEFT", 16, -16)
	header:SetText(title)
	
	-- Tagline
	local tag = self:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	tag:SetPoint("TOPLEFT", header, "BOTTOMLEFT", 0, -5)
	tag:SetText(desc)
	
	-- Hide when empty
	local hide = CreateFrame("CheckButton", "PowerUpHideCheck", f, "InterfaceOptionsCheckButtonTemplate")
	hide:SetChecked(db.hidewhenempty)
	hide:SetScript("OnClick", function(self)
		db.hidewhenempty = not db.hidewhenempty
		PowerUp:PLAYER_ENTERING_WORLD()
	end)
	hide:SetPoint("TOPLEFT", tag, "BOTTOMLEFT", 0, -20)
	_G[hide:GetName() .. "Text"]:SetText("Hide the bar when empty")
	hide.tooltipText = "Hide"
	hide.tooltipRequirement = "Toggle to hide the bar when you have no charges."
	
	-- Hide Blizzard
	local hb = CreateFrame("CheckButton", "PowerUpHideBlizzCheck", f, "InterfaceOptionsCheckButtonTemplate")
	hb:SetChecked(db.hideBlizz)
	hb:SetScript("OnClick", function(self)
		db.hideBlizz = not db.hideBlizz
		PowerUp:HideBlizzard()
	end)
	hb:SetPoint("TOPLEFT", hide, "BOTTOMLEFT", 0, -2)
	_G[hb:GetName() .. "Text"]:SetText("Hide Blizzard frames")
	hb.tooltipText = "Hide Blizzard"
	hb.tooltipRequirement = "Toggle to hide Blizzards own frames."	
	
	local width = CreateFrame("Slider", "PowerUpWidthSlider", f, "OptionsSliderTemplate")
	width.text = _G[width:GetName() .. "Text"]
	width:SetValueStep(1)
	width:SetMinMaxValues(50, 300)
	width:SetScript("OnValueChanged", function(self)
		db.width = self:GetValue()
		width.text:SetText(string.format("Width: %d", db.width))
		PowerUp:Paintshop()
	end)
	width:SetPoint("TOPLEFT", hb, "BOTTOMLEFT", 0, -20)
	width:SetValue(db.width)
	width.text:SetText(string.format("Width: %d", db.width))
	width.tooltipText = "Width"
	width.tooltipRequirement = "Set the width of the frame."	
	
	local height = CreateFrame("Slider", "PowerUpHeightSlider", f, "OptionsSliderTemplate")
	height.text = _G[height:GetName() .. "Text"]
	height:SetValueStep(1)
	height:SetMinMaxValues(5, 25)
	height:SetScript("OnValueChanged", function(self)
		db.height = self:GetValue()
		height.text:SetText(string.format("Height: %d", db.height))
		PowerUp:Paintshop()
	end)
	height:SetPoint("LEFT", width, "RIGHT", 50, 0)
	height:SetValue(db.height)
	height.text:SetText(string.format("Height: %d", db.height))
	height.tooltipText = "Height"
	height.tooltipRequirement = "Set the height of the frame."
	
	if PowerUp.class == "PALADIN" then
		local header = self:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		header:SetText("Paladin")
		header:SetPoint("TOPLEFT", width, "BOTTOMLEFT", 0, -50)
		
		-- Overlay
		local overlay = CreateFrame("CheckButton", "PowerUpOverlayCheck", f, "InterfaceOptionsCheckButtonTemplate")
		overlay:SetChecked(db.showOverlay)
		overlay:SetScript("OnClick", function(self)
			db.showOverlay = not db.showOverlay
			PowerUp:ToggleOverlay()
		end)
		overlay:SetPoint("TOPLEFT", header, "BOTTOMLEFT", 0, -5)
		_G[overlay:GetName() .. "Text"]:SetText("Show overlay")
		overlay.tooltipText = "Overlay"
		overlay.tooltipRequirement = "Toggle to display the overlay. Please note that you might have to lose or gain a charge for this to take proper effect."		
		
		-- Gradient
		local gradient = CreateFrame("CheckButton", "PowerUpGradientCheck", f, "InterfaceOptionsCheckButtonTemplate")
		gradient:SetChecked(db.useGradient)
		gradient:SetScript("OnClick", function(self)
			db.useGradient = not db.useGradient
			PowerUp:ToggleOverlay()
		end)
		gradient:SetPoint("TOPLEFT", overlay, "BOTTOMLEFT", 0, -2)
		_G[gradient:GetName() .. "Text"]:SetText("Color overlay with gradient")
		gradient.tooltipText = "Gradient"
		gradient.tooltipRequirement = "Toggle to color the overlay with a gradient ranging from green to red."	
	end
	
	self:SetScript("OnShow", nil)
end)

InterfaceOptions_AddCategory(f)